{
    "$graph": [
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "expression": " ${ inputs.main_file.secondaryFiles = Array.isArray(inputs.secondary_files) ? inputs.secondary_files : [inputs.secondary_files];\nreturn { \"file_with_secondary_files\": inputs.main_file } } ",
            "doc": "Step to put secondary input files in the same folder as a main file",
            "inputs": [
                {
                    "type": "File",
                    "id": "#combine_files.cwl/main_file"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#combine_files.cwl/secondary_files"
                }
            ],
            "id": "#combine_files.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#combine_files.cwl/file_with_secondary_files"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/capmq:v1"
                },
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envValue": "$(inputs.ref_path_dir.path)/%2s/%2s/%s",
                            "envName": "REF_PATH"
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "capmq"
            ],
            "inputs": [
                {
                    "id": "#capmq.cwl/ref_path_dir",
                    "type": [
                        "null",
                        "Directory"
                    ]
                },
                {
                    "id": "#capmq.cwl/input_file",
                    "inputBinding": {
                        "position": 1
                    },
                    "type": "File"
                },
                {
                    "id": "#capmq.cwl/output_filename",
                    "default": "",
                    "inputBinding": {
                        "position": 2,
                        "valueFrom": "$(self || inputs.input_file.basename)"
                    },
                    "type": "string"
                },
                {
                    "id": "#capmq.cwl/MAPQ_cap",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Cap MAPQ at max (default: 255)"
                },
                {
                    "id": "#capmq.cwl/dont_store_in_omi_aux_tag",
                    "inputBinding": {
                        "prefix": "-S"
                    },
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Do not store original MAPQ in om:i aux tag"
                },
                {
                    "id": "#capmq.cwl/restore_mapq",
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "doc": "Restore original MAPQ from om:i aux tag",
                    "type": [
                        "null",
                        "boolean"
                    ]
                },
                {
                    "id": "#capmq.cwl/verbose",
                    "inputBinding": {
                        "prefix": "-v"
                    },
                    "doc": "verbose",
                    "type": [
                        "null",
                        "boolean"
                    ]
                },
                {
                    "id": "#capmq.cwl/readgroup_caps",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "doc": "Cap MAPQ for read group IDs.\nThis can be specified more than once, and if specified\nwill override the -C paramater for those read groups.\n",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": {
                                "type": "record",
                                "fields": [
                                    {
                                        "name": "#capmq.cwl/readgroup_caps/read_group",
                                        "type": "string"
                                    },
                                    {
                                        "name": "#capmq.cwl/readgroup_caps/cap_value",
                                        "type": "float"
                                    }
                                ]
                            },
                            "inputBinding": {
                                "valueFrom": "$(self.map(function (item){return item.read_group + \":\" + item.cap_value}))"
                            }
                        }
                    ]
                },
                {
                    "id": "#capmq.cwl/readgroup_caps_file",
                    "inputBinding": {
                        "prefix": "-G"
                    },
                    "doc": "As for -g, but group ID/max value pairs are read from a tab delimited file.",
                    "type": [
                        "null",
                        "File"
                    ]
                },
                {
                    "id": "#capmq.cwl/use_max_contamination",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "The values to -C, -g or in the file specified with -G\nare NOT maximum MAPQ scores, but estimated fraction of\ncontamination (e) from which to calculate the maximum\nMAPQ as int(10*log10(1/e)).\n"
                },
                {
                    "id": "#capmq.cwl/minimum_MAPQ",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Minimum MAPQ. Do not set the calculated quality\nto less than this value. Only used with -f\n(default: 0)\n"
                },
                {
                    "id": "#capmq.cwl/htslib_input_options",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-I"
                    },
                    "doc": "Input format and format-options.\nThis is passed in through a object which has fields of the options set\nplus a compulsory file_format to set the file format.\n"
                },
                {
                    "id": "#capmq.cwl/htslib_output_options",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "doc": "Output format and format-options [SAM].\nThis is passed in through a object which has fields of the options set\nplus a compulsory file_format to set the file format.\n"
                }
            ],
            "outputs": [
                {
                    "id": "#capmq.cwl/capped_file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename || inputs.input_file.basename)"
                    }
                }
            ],
            "id": "#capmq.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "mercury/get-read-group-caps:v3",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "/get_read_group_caps.py"
            ],
            "inputs": [
                {
                    "id": "#get_read_group_caps.cwl/read_groups",
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--read_groups"
                        }
                    }
                },
                {
                    "id": "#get_read_group_caps.cwl/verify_bam_id_files",
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--verify_bam_id_files"
                        }
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#get_read_group_caps.cwl/read_group_caps_file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "caps_file"
                    }
                }
            ],
            "id": "#get_read_group_caps.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "bash",
                "-c"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/samtools-1.6:v2"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "arguments": [
                "samtools view -H $(inputs.cram.path) | awk 'BEGIN {\n  FS=\"\\\\t\";\n} /^@RG/ {\n  for(i=1;i<=NF;i++) {\n    if($i~/^ID:/) {\n      print substr($i,4);\n    }\n  }\n}' > $(inputs.filename)\n"
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input file with header to be simplified\n",
                    "id": "#list_rgs.cwl/cram"
                },
                {
                    "type": "string",
                    "default": "rg_list.sam",
                    "doc": "Output file name of rg list\n",
                    "id": "#list_rgs.cwl/filename"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "$(inputs.filename)",
                        "outputEval": "$(self[0].contents.split(\"\\n\").slice(0, -1))"
                    },
                    "id": "#list_rgs.cwl/rg_values"
                }
            ],
            "id": "#list_rgs.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/samtools-1.6:v2"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Generate BAI-format index for BAM files [default]",
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "id": "#samtools-index.cwl/generate_bai_index"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Generate CSI-format index for BAM files",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#samtools-index.cwl/generate_csi_index"
                },
                {
                    "type": "File",
                    "doc": "Input bam file.",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#samtools-index.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#samtools-index.cwl/minimum_interval_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "id": "#samtools-index.cwl/number_of_threads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "$(self || inputs.input.basename + \".crai\")"
                    },
                    "doc": "Filename of the the output file",
                    "id": "#samtools-index.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename || inputs.input.basename + \".crai\")"
                    },
                    "id": "#samtools-index.cwl/cram_index"
                }
            ],
            "baseCommand": [
                "samtools",
                "index"
            ],
            "id": "#samtools-index.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "mercury/samtools-seq_cache_populate",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "seq_cache_populate.pl"
            ],
            "arguments": [
                {
                    "prefix": "-root",
                    "valueFrom": "$(runtime.outdir)",
                    "position": 1
                }
            ],
            "inputs": [
                {
                    "id": "#samtools_seq_cache_populate.cwl/ref_fasta_files",
                    "doc": "Reference fasta files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": null,
                        "position": 2
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#samtools_seq_cache_populate.cwl/ref_cache",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "."
                    }
                }
            ],
            "id": "#samtools_seq_cache_populate.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "mercury/verifybamid2-1.0.4-samtools-1.6:v3",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "verifybamid_rg"
            ],
            "inputs": [
                {
                    "id": "#verifybamid2-rg.cwl/cram",
                    "doc": "Input cram file",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--cram-file"
                    }
                },
                {
                    "id": "#verifybamid2-rg.cwl/rg",
                    "doc": "Read group",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--rg"
                    }
                },
                {
                    "id": "#verifybamid2-rg.cwl/ref",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--ref-file"
                    }
                },
                {
                    "id": "#verifybamid2-rg.cwl/svdset",
                    "doc": "SVD set to use",
                    "type": "string",
                    "default": "hgdp.100k",
                    "inputBinding": {
                        "prefix": "--svd-set"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#verifybamid2-rg.cwl/out-file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.out"
                    }
                }
            ],
            "id": "#verifybamid2-rg.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/library_cram",
                    "type": "File"
                },
                {
                    "id": "#main/reference_fasta",
                    "type": "File"
                }
            ],
            "steps": [
                {
                    "id": "#main/get_rg_values",
                    "run": "#list_rgs.cwl",
                    "in": [
                        {
                            "source": "#main/library_cram",
                            "id": "#main/get_rg_values/cram"
                        }
                    ],
                    "out": [
                        "#main/get_rg_values/rg_values"
                    ]
                },
                {
                    "id": "#main/verify_bam_id",
                    "run": "#verifybamid2-rg.cwl",
                    "scatter": "#main/verify_bam_id/rg",
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/library_cram",
                            "id": "#main/verify_bam_id/cram"
                        },
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/verify_bam_id/ref"
                        },
                        {
                            "source": "#main/get_rg_values/rg_values",
                            "id": "#main/verify_bam_id/rg"
                        }
                    ],
                    "out": [
                        "#main/verify_bam_id/out-file"
                    ]
                },
                {
                    "id": "#main/get_read_group_caps",
                    "run": "#get_read_group_caps.cwl",
                    "in": [
                        {
                            "source": "#main/get_rg_values/rg_values",
                            "id": "#main/get_read_group_caps/read_groups"
                        },
                        {
                            "source": "#main/verify_bam_id/out-file",
                            "id": "#main/get_read_group_caps/verify_bam_id_files"
                        }
                    ],
                    "out": [
                        "#main/get_read_group_caps/read_group_caps_file"
                    ]
                },
                {
                    "id": "#main/get_capmq_ref_cache",
                    "run": "#samtools_seq_cache_populate.cwl",
                    "in": [
                        {
                            "source": "#main/reference_fasta",
                            "valueFrom": "$([self])",
                            "id": "#main/get_capmq_ref_cache/ref_fasta_files"
                        }
                    ],
                    "out": [
                        "#main/get_capmq_ref_cache/ref_cache"
                    ]
                },
                {
                    "id": "#main/capmq",
                    "run": "#capmq.cwl",
                    "in": [
                        {
                            "valueFrom": "cram",
                            "id": "#main/capmq/htslib_output_options"
                        },
                        {
                            "source": "#main/library_cram",
                            "id": "#main/capmq/input_file"
                        },
                        {
                            "default": 20,
                            "id": "#main/capmq/minimum_MAPQ"
                        },
                        {
                            "source": "#main/library_cram",
                            "valueFrom": "$(self.nameroot).capmq.cram",
                            "id": "#main/capmq/output_filename"
                        },
                        {
                            "source": "#main/get_read_group_caps/read_group_caps_file",
                            "id": "#main/capmq/readgroup_caps_file"
                        },
                        {
                            "source": "#main/get_capmq_ref_cache/ref_cache",
                            "id": "#main/capmq/ref_path_dir"
                        },
                        {
                            "default": true,
                            "id": "#main/capmq/use_max_contamination"
                        }
                    ],
                    "out": [
                        "#main/capmq/capped_file"
                    ]
                },
                {
                    "id": "#main/cram_index",
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#main/capmq/capped_file",
                            "id": "#main/cram_index/input"
                        }
                    ],
                    "out": [
                        "#main/cram_index/cram_index"
                    ]
                },
                {
                    "id": "#main/combine_cram_index",
                    "run": "#combine_files.cwl",
                    "in": [
                        {
                            "source": "#main/capmq/capped_file",
                            "id": "#main/combine_cram_index/main_file"
                        },
                        {
                            "source": "#main/cram_index/cram_index",
                            "id": "#main/combine_cram_index/secondary_files"
                        }
                    ],
                    "out": [
                        "#main/combine_cram_index/file_with_secondary_files"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#main/capped_file",
                    "type": "File",
                    "outputSource": "#main/combine_cram_index/file_with_secondary_files"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
